@@ -25,6 +25,8 @@ class TaskWithReference(tasks.PuppetTask, waluigi_tasks.WaluigiTaskMixin):
     puppet_account_id = luigi.Parameter()
     manifest_files_path = luigi.Parameter()
 
+    task_version = "latest"
+
     def requires(self):
         return dict(reference_dependencies=self.dependencies_for_task_reference())
 
@@ -33,6 +35,9 @@ class TaskWithReference(tasks.PuppetTask, waluigi_tasks.WaluigiTaskMixin):
             content = f.read()
         return serialisation_utils.json_loads(content)
 
+    def get_attribute_from_output_from_reference_dependency(self, attribute, reference):
+        return self.get_output_from_reference_dependency(reference).get(attribute)
+
     def get_output_from_reference_dependency_raw(self, reference):
         f = self.input().get("reference_dependencies").get(reference).open("r")
         content = f.read()
@@ -77,7 +82,12 @@ class TaskWithReference(tasks.PuppetTask, waluigi_tasks.WaluigiTaskMixin):
         return f"{self.task_reference}"
 
     def get_output_location_path(self):
-        return f"output/{self.__class__.__name__}/{self.task_reference}/{self.params_for_results_display().get('cache_invalidator', 'latest')}.{self.output_suffix}"
+        return f"output/{self.__class__.__name__}/{self.task_reference}/{self.params_for_results_display().get('cache_invalidator', self.task_version)}.{self.output_suffix}"
+
+
+class TaskWithReferenceAndCommonParameters(TaskWithReference):
+    region = luigi.Parameter()
+    account_id = luigi.Parameter()
 
 
 class TaskWithParameters(TaskWithReference):
