@@ -10,6 +10,8 @@ class ShareAndAcceptPortfolioForAccountTaskTest(
     portfolio = "portfolio"
     portfolio_task_reference = "portfolio_task_reference"
     share_tag_options = True
+    share_principals = True
+    describe_portfolio_shares_task_ref = "describe_portfolio_shares_task_ref"
 
     def setUp(self) -> None:
         from servicecatalog_puppet.workflow.portfolio.sharing_management import (
@@ -25,6 +27,8 @@ class ShareAndAcceptPortfolioForAccountTaskTest(
             portfolio=self.portfolio,
             portfolio_task_reference=self.portfolio_task_reference,
             share_tag_options=self.share_tag_options,
+            share_principals=self.share_principals,
+            describe_portfolio_shares_task_ref = self.describe_portfolio_shares_task_ref,
         )
 
         self.wire_up_mocks()
@@ -38,6 +42,8 @@ class ShareAndAcceptPortfolioForAccountTaskTest(
             "region": self.region,
             "account_id": self.account_id,
             "share_tag_options": self.share_tag_options,
+            "share_principals": self.share_principals,
+            "cache_invalidator": self.cache_invalidator,
         }
 
         # exercise
